@@ -45,11 +45,11 @@ Geo::Coder::Free::MaxMind - Provides a geocoding functionality using the MaxMind
 
 =head1 VERSION
 
-Version 0.34
+Version 0.35
 
 =cut
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 =head1 SYNOPSIS
 
@@ -120,12 +120,10 @@ sub new {
 		return bless { %{$class}, %args }, ref($class);
 	}
 
-	# Geo::Coder::Free::DB::init(directory => 'lib/Geo/Coder/Free/databases');
-
 	my $directory = $args{'directory'} || Module::Info->new_from_loaded(__PACKAGE__)->file();
 	$directory =~ s/\.pm$//;
 
-	Geo::Coder::Free::DB::init({
+	Database::Abstraction::init({
 		cache_duration => '1 day',
 		%args,
 		directory => File::Spec->catfile($directory, 'databases'),
