@@ -47,11 +47,11 @@ Provides a geocoding functionality to a local SQLite database containing geo-cod
 
 =head1 VERSION
 
-Version 0.34
+Version 0.35
 
 =cut
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 =head1 SYNOPSIS
 
@@ -104,7 +104,7 @@ sub new {
 	return unless($class);
 
 	if(my $openaddr = $param{'openaddr'}) {
-		Carp::croak "Can't find the directory $openaddr"
+		Carp::croak("Can't find the directory $openaddr")
 			if((!-d $openaddr) || (!-r $openaddr));
 		return bless { openaddr => $openaddr, cache => $param{'cache'} }, $class;
 	}
@@ -171,39 +171,40 @@ sub geocode {
 				if($addr =~ /\s+(\d{2,5}\s+)(?![a|p]m\b)(([a-zA-Z|\s+]{1,5}){1,2})?([\s|\,|.]+)?(([a-zA-Z|\s+]{1,30}){1,4})(court|ct|street|st|drive|dr|lane|ln|road|rd|blvd)([\s|\,|.|\;]+)?(([a-zA-Z|\s+]{1,30}){1,2})([\s|\,|.]+)?\b(AK|AL|AR|AZ|CA|CO|CT|DC|DE|FL|GA|GU|HI|IA|ID|IL|IN|KS|KY|LA|MA|MD|ME|MI|MN|MO|MS|MT|NC|ND|NE|NH|NJ|NM|NV|NY|OH|OK|OR|PA|RI|SC|SD|TN|TX|UT|VA|VI|VT|WA|WI|WV|WY)([\s|\,|.]+)?(\s+\d{5})?([\s|\,|.]+)/i) {
 					if(($l = $self->geocode(location => "$addr, US")) && ref($l)) {
 						$l->confidence(0.8);
-						$l->location("$addr, USA");
 						$l->country('US');
+						$l->location("$addr, USA");
 						push @rc, $l;
 					}
 				} elsif($addr =~ /\s+(\d{2,5}\s+)(?![a|p]m\b)(([a-zA-Z|\s+]{1,5}){1,2})?([\s|\,|.]+)?(([a-zA-Z|\s+]{1,30}){1,4})(court|ct|street|st|drive|dr|lane|ln|road|rd|blvd)([\s|\,|.|\;]+)?(([a-zA-Z|\s+]{1,30}){1,2})([\s|\,|.]+)?\b(AB|BC|MB|NB|NL|NT|NS|ON|PE|QC|SK|YT)([\s|\,|.]+)?(\s+\d{5})?([\s|\,|.]+)/i) {
 					if(($l = $self->geocode(location => "$addr, Canada")) && ref($l)) {
 						$l->confidence(0.8);
-						$l->location("$addr, Canada");
 						$l->country('CA');
+						$l->location("$addr, Canada");
 						push @rc, $l;
 					}
 				} elsif($addr =~ /([a-zA-Z|\s+]{1,30}){1,2}([\s|\,|.]+)?\b(AK|AL|AR|AZ|CA|CO|CT|DC|DE|FL|GA|GU|HI|IA|ID|IL|IN|KS|KY|LA|MA|MD|ME|MI|MN|MO|MS|MT|NC|ND|NE|NH|NJ|NM|NV|NY|OH|OK|OR|PA|RI|SC|SD|TN|TX|UT|VA|VI|VT|WA|WI|WV|WY)/i) {
 					if(($l = $self->geocode(location => "$addr, US")) && ref($l)) {
 						$l->confidence(0.6);
-						$l->location("$addr, USA");
 						$l->city(uc($1));
 						$l->state(uc($3));
 						$l->country('US');
+						$l->location(uc("$addr, USA"));
 						push @rc, $l;
 					}
 				} elsif($addr =~ /([a-zA-Z|\s+]{1,30}){1,2}([\s|\,|.]+)?\b(AB|BC|MB|NB|NL|NT|NS|ON|PE|QC|SK|YT)/i) {
 					if(($l = $self->geocode(location => "$addr, Canada")) && ref($l)) {
 						$l->confidence(0.6);
-						$l->location("$addr, Canada");
 						$l->city(uc($1));
 						$l->state(uc($3));
-						$l->country('US');
+						$l->country('Canada');
+						$l->location(uc("$addr, Canada"));
 						push @rc, $l;
 					}
 				}
 				if(($l = $self->geocode(location => $addr)) && ref($l)) {
 					$l->confidence(0.1);
 					$l->location($addr);
+					::diag(__LINE__, ": $addr");
 					push @rc, $l;
 				}
 				if($offset < $count - 2) {
@@ -308,7 +309,7 @@ sub geocode {
 		if($l =~ /(.+), (England|UK)$/i) {
 			$l = "$1, GB";
 		}
-		if(my $error = $ap->parse($l)) {
+		if($ap->parse($l)) {
 			# Carp::croak($ap->report());
 			# ::diag('Address parse failed: ', $ap->report());
 		} else {
@@ -880,8 +881,15 @@ sub _get {
 	my $location = join('', @location);
 	$location =~ s/^\s+//;
 	$location =~ s/,\s*//g;
+
 	# ::diag(__PACKAGE__, ': ', __LINE__, ": _get: $location");
-	my $digest = substr Digest::MD5::md5_base64(uc($location)), 0, 16;
+	my $digest;
+	if(length($location) <= 16) {
+		$digest = uc($location);
+	} else {
+		$digest = substr Digest::MD5::md5_base64(uc($location)), 0, 16;
+	}
+	# print __PACKAGE__, ': ', __LINE__, ': ', uc($location), " = $digest\n";
 
 	if(defined($unknown_locations{$digest})) {
 		return;
@@ -939,7 +947,7 @@ To be done.
 
 =cut
 
-# At the moment this can't be supported as the DB only has an MD5 in it
+# At the moment this can't be supported as the DB only has an hash in it
 sub reverse_geocode {
 	Carp::croak(__PACKAGE__, ': Reverse lookup is not yet supported');
 }
